using Microsoft.Xna.Framework;

namespace MicroStar
{
    /// <summary>
    /// Modifier to change particle color based on particle age
    /// </summary>
    public class ColorAgeTransform : Modifier
    {
        internal override void Update(float particleAge, double totalMilliseconds, double elapsedSeconds, Particle particle)
        {
            int r = (int)MathHelper.Lerp(StartColor.R, EndColor.R, particleAge);
            int g = (int)MathHelper.Lerp(StartColor.G, EndColor.G, particleAge);
            int b = (int)MathHelper.Lerp(StartColor.B, EndColor.B, particleAge);

            particle.Color = new Color((byte)r, (byte)g, (byte)b);
        }

        /// <summary>
        /// Gets or sets the starting color
        /// </summary>
        public Color StartColor { get; set; }

        /// <summary>
        /// Gets or sets the end color
        /// </summary>
        public Color EndColor { get; set; }
    }
}
