using Microsoft.Xna.Framework;

namespace MicroStar
{
    /// <summary>
    /// Modifier to scale particles based on age
    /// </summary>
    public class ScaleAgeTransform : Modifier
    {
        private Vector2 currentScale;

        internal override void Update(float particleAge, double totalMilliseconds, double elapsedSeconds, Particle particle)
        {
            float age = (float)(totalMilliseconds - particle.Inception);

            if (age < particle.Lifespan)
            {
                currentScale.X = MathHelper.Lerp(StartScale.X, EndScale.X, age / particle.Lifespan);
                currentScale.Y = MathHelper.Lerp(StartScale.Y, EndScale.Y, age / particle.Lifespan);
            }
            else
                currentScale = EndScale;

            particle.Scale = currentScale;
        }

        /// <summary>
        /// Gets or sets the particle starting scale
        /// </summary>
        public Vector2 StartScale { get; set; }

        /// <summary>
        /// Gets or sets the particle end scale
        /// </summary>
        public Vector2 EndScale { get; set; }
    }
}
